pub struct WebviewUri(pub String);Expand description
The Uri that load in the webview.
If you want to load a local resource, use custom protocol: flurx://localhost/<ROOT>/<uri>.
<ROOT> is specified in the plugin field or Resource of the crate that actually implements the Webview.
Default is flurx://localhost/.
Tuple Fields
0: StringImplementations
Sourceimpl WebviewUri
impl WebviewUri
Sourcepub fn new(uri: impl Into<String>) -> Self
pub fn new(uri: impl Into<String>) -> Self
Returns the new WebviewUri.
Sourcepub fn relative_local(uri: impl AsRef<Path>) -> Self
pub fn relative_local(uri: impl AsRef<Path>) -> Self
Returns the webview uri to load a local resource.
The url will be in the form of a custom protocol: flurx://localhost/<ROOT>/<uri>.
<ROOT> is specified in the plugin field or Resource of the crate that actually implements the Webview.